# API Star Token Based Authentication

Token Based Authentication for API Star

![](docs/docs.gif)

## Installation

```
$ pip install apistar-token-authentication
```

# Docs
- [Django Setup](docs/DJANGO_SETUP.md)
- [SQLAlchemy Setup](docs/SQLALCHEMY_SETUP.md)
- [Configuration](docs/CONFIGURATION.md)

## Example

- [Django Example](examples/django)
- [SQLAlchemy Example](examples/sqlalchemy)
